@@ -24,8 +24,9 @@ class RiakClient(object):
     """
     def __init__(self, host='127.0.0.1', port=8098,
                 prefix='riak', mapred_prefix='mapred',
-                client_id=None, r_value="default", w_value="default", dw_value="default",
-                transport=transport.HTTPTransport):
+                client_id=None, r_value="default", w_value="default",
+                dw_value="default", transport=transport.HTTPTransport,
+                request_timeout=None):
         """
         Construct a new RiakClient object.
 
@@ -54,7 +55,12 @@ class RiakClient(object):
                           'text/json': json.loads}
         self._solr = None
 
-        self.transport = transport(self) 
+        self.request_timeout = request_timeout
+
+        self.transport = transport(self)
+
+    def setRequestTimeout(self, timeout):
+        self.request_timeout = timeout
 
     def get_transport(self):
         return self.transport
@@ -77,8 +83,8 @@ class RiakClient(object):
 
     def set_rw(self, rw):
         """
-        Set the RW-value for this ``RiakClient`` instance. See :func:`set_r` for a
-        description of how these values are used.
+        Set the RW-value for this ``RiakClient`` instance. See :func:`set_r`
+        for a description of how these values are used.
 
         :param rw: The RW value.
         :type rw: integer
@@ -97,8 +103,8 @@ class RiakClient(object):
 
     def set_pw(self, pw):
         """
-        Set the PW-value for this ``RiakClient`` instance. See :func:`set_r` for a
-        description of how these values are used.
+        Set the PW-value for this ``RiakClient`` instance. See :func:`set_r`
+        for a description of how these values are used.
 
         :param pw: The W value.
         :type pw: integer
@@ -117,8 +123,8 @@ class RiakClient(object):
 
     def set_pr(self, pr):
         """
-        Set the PR-value for this ``RiakClient`` instance. See :func:`set_r` for a
-        description of how these values are used.
+        Set the PR-value for this ``RiakClient`` instance. See :func:`set_r`
+        for a description of how these values are used.
 
         :param pr: The PR value.
         :type pr: integer
